"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.datoToNumber = exports.DaysInMonth = exports.addDays = exports.convert = exports.format = void 0;
function format(locale, value, separator) {
    if (!separator)
        separator = "/";
    var date = new Date(String(value));
    var monthName = new Intl.DateTimeFormat(locale, {
        month: "long",
    }).format(date);
    var fmt = new Intl.DateTimeFormat(locale, {
        weekday: "long",
        day: "numeric",
        month: "numeric",
        year: "numeric",
        hour: "numeric",
        minute: "numeric",
        second: "numeric",
        hour12: false,
    })
        .formatToParts(date)
        .reduce(function (acc, part) {
        acc[part.type] = toEnglishNumber(String(part.value));
        return acc;
    }, {});
    fmt.month = fmt.month.toString().padStart(2, "0");
    fmt.day = fmt.day.toString().padStart(2, "0");
    return {
        YYYY_MM_dd_HH_MM_ss: "".concat(fmt.year + separator + fmt.month + separator + fmt.day, " ").concat(fmt.hour, ":").concat(fmt.minute, ":").concat(fmt.second),
        YYYY_MM_dd_HH_MM: "".concat(fmt.year + separator + fmt.month + separator + fmt.day, " ").concat(fmt.hour, ":").concat(fmt.minute),
        HH_MM_ss: "".concat(fmt.hour, ":").concat(fmt.minute, ":").concat(fmt.second),
        HH_MM: "".concat(fmt.hour, ":").concat(fmt.minute),
        YYYY_MM_dd: "".concat(fmt.year + separator + fmt.month + separator + fmt.day),
        YYYY_M_dd: " ".concat(fmt.day, " ").concat(monthName, " ").concat(fmt.year),
        YYYY_M: "".concat(fmt.year, " ").concat(monthName),
        W_YYYY_M_dd: "".concat(fmt.weekday, " ").concat(fmt.day, " ").concat(monthName, " ").concat(fmt.year),
        W_dd_M: "".concat(fmt.weekday, " ").concat(fmt.day, " ").concat(monthName),
        dd_M: "".concat(fmt.day, " ").concat(monthName),
        YYYY: "".concat(fmt.year),
        MM: fmt.month,
        M: monthName,
        d: fmt.day,
        W: "".concat(fmt.weekday),
        WW: getWeekdayNumber(fmt.weekday, locale).toString(),
        Unix: Math.floor(new Date(date).getTime() / 1000),
    };
}
exports.format = format;
function convert(locale, value, separator) {
    if (locale.toLocaleLowerCase() === "fa") {
        return format("fa", value, separator);
    }
    else {
        // Assuming toGregorian is implemented elsewhere
        return toGregorian(value, separator);
    }
}
exports.convert = convert;
function addDays(locale, value, days, separator) {
    var _a;
    if (locale.toLocaleLowerCase() === "fa") {
        var date = new Date((_a = convert("en", value)) === null || _a === void 0 ? void 0 : _a.YYYY_MM_dd);
        date.setDate(date.getDate() + days);
        return format("fa", date, separator);
    }
    else {
        var date = new Date(String(value));
        date.setDate(date.getDate() + days);
        return format("en", date, separator);
    }
}
exports.addDays = addDays;
function DaysInMonth(locale, year, month) {
    var _a, _b;
    if (locale.toLowerCase() === "fa") {
        var date1 = new Date((_a = convert("en", "".concat(year, "/").concat(month, "/1"))) === null || _a === void 0 ? void 0 : _a.YYYY_MM_dd);
        if (month === 12) {
            year++;
            month = 1;
        }
        else {
            month++;
        }
        var date2 = new Date((_b = convert("en", "".concat(year, "/").concat(month, "/1"))) === null || _b === void 0 ? void 0 : _b.YYYY_MM_dd);
        return Math.round((date2.getTime() - date1.getTime()) / (1000 * 60 * 60 * 24));
    }
    else {
        var d = new Date(year, month, 0);
        return d.getDate();
    }
}
exports.DaysInMonth = DaysInMonth;
function datoToNumber(date) {
    return Number(toEnglishNumber(String(date).replace(/\//g, "").replace(/-/g, "")));
}
exports.datoToNumber = datoToNumber;
//#region private functions
function toEnglishNumber(value) {
    if (value == null)
        return "";
    var englishNumbers = "0123456789";
    var persianNumbers1 = "٠١٢٣۴۵۶٧٨٩";
    var persianNumbers2 = "۰۱۲۳۴۵۶۷۸۹";
    var arabicNumbers = "٠١٢٣٤٥٦٧٨٩";
    var res = "";
    // @ts-ignore
    for (var _i = 0, value_1 = value; _i < value_1.length; _i++) {
        var c = value_1[_i];
        var index1 = persianNumbers1.indexOf(c);
        var index2 = persianNumbers2.indexOf(c);
        var index3 = arabicNumbers.indexOf(c);
        var index = index1 >= 0 ? index1 : index2 >= 0 ? index2 : index3;
        res += index >= 0 ? englishNumbers[index] : c;
    }
    return res;
}
function toGregorian(value, separator) {
    // Implementation of toGregorian is not provided, please add it if necessary
    // Assuming toGregorian is implemented elsewhere
    var JalaliDate = {
        g_days_in_month: [31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31],
        j_days_in_month: [31, 31, 31, 31, 31, 31, 30, 30, 30, 30, 30, 29],
    };
    if (!separator)
        separator = "/";
    var literal = String(value).indexOf("-") > 0 ? "-" : "/";
    var j_y = +toEnglishNumber(String(value).split(literal)[0]);
    var j_m = +toEnglishNumber(String(value).split(literal)[1]);
    var j_d = +toEnglishNumber(String(value).split(literal)[2]);
    if (value != null) {
        var jy = j_y - 979;
        var jm = j_m - 1;
        var jd = j_d - 1;
        var j_day_no = 365 * jy + Math.floor(jy / 33) * 8 + Math.floor(((jy % 33) + 3) / 4);
        for (var i_1 = 0; i_1 < jm; ++i_1) {
            j_day_no += JalaliDate.j_days_in_month[i_1];
        }
        j_day_no += jd;
        var g_day_no = j_day_no + 79;
        var gy = 1600 +
            400 *
                Math.floor(g_day_no / 146097); /* 146097 = 365*400 + 400/4 - 400/100 + 400/400 */
        g_day_no = g_day_no % 146097;
        var leap = true;
        if (g_day_no >= 36525) {
            /* 36525 = 365*100 + 100/4 */
            g_day_no--;
            gy +=
                100 *
                    Math.floor(g_day_no / 36524); /* 36524 = 365*100 + 100/4 - 100/100 */
            g_day_no = g_day_no % 36524;
            if (g_day_no >= 365)
                g_day_no++;
            else
                leap = false;
        }
        gy += 4 * Math.floor(g_day_no / 1461); /* 1461 = 365*4 + 4/4 */
        g_day_no %= 1461;
        if (g_day_no >= 366) {
            leap = false;
            g_day_no--;
            gy += Math.floor(g_day_no / 365);
            g_day_no = g_day_no % 365;
        }
        // let i: number;
        // for (i = 0; g_day_no >= JalaliDate.g_days_in_month[i] + (i === 1 && leap); i++) {
        //   g_day_no -= JalaliDate.g_days_in_month[i] + (i === 1 && leap);
        // }
        var i = void 0;
        for (i = 0; g_day_no >= JalaliDate.g_days_in_month[i] + (i === 1 && leap ? 1 : 0); i++) {
            g_day_no -= JalaliDate.g_days_in_month[i] + (i === 1 && leap ? 1 : 0);
        }
        var gm = i + 1;
        var gd = g_day_no + 1;
        gm = gm < 10 ? 0 + gm : gm;
        gd = gd < 10 ? 0 + gd : gd;
        return format("en", new Date("".concat(gy + separator + gm + separator + gd)), separator);
    }
    else {
        return format("en", new Date(), separator);
    }
}
function getWeekdayNumber(weekdayString, locale) {
    if (locale === "en") {
        return [
            "Saturday",
            "Sunday",
            "Monday",
            "Tuesday",
            "Wednesday",
            "Thursday",
            "Friday",
        ].indexOf(weekdayString);
    }
    else {
        return [
            "شنبه",
            "یکشنبه",
            "دوشنبه",
            "سه‌شنبه",
            "چهارشنبه",
            "پنجشنبه",
            "جمعه",
        ].indexOf(weekdayString);
    }
}
//# sourceMappingURL=date.js.map